@@ -296,6 +296,10 @@ def search(
     with console.status(f"Searching for {name}..."):
         response = requests.get(url, headers=headers, params=parameters)
 
+    if response.status_code == 404:
+        console.print(f"[bold]The specified page doesn't exist[/]")
+        raise typer.Exit()
+
     with console.status("Parsing data..."):
         soup = bs4.BeautifulSoup(response.text, "lxml")
         result_list = soup.find(attrs={"aria-label": "Search results"}, class_="unstyled")
